## Typing stubs for punq

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`punq`](https://github.com/bobthemighty/punq) package. It can be used by type checkers
to check code that uses `punq`. This version of
`types-punq` aims to provide accurate annotations for
`punq==0.7.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/punq`](https://github.com/python/typeshed/tree/main/stubs/punq)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.19.1
* [pyright](https://github.com/microsoft/pyright) 1.1.408

It was generated from typeshed commit
[`4992a813c160e037712b0793cd0488275cb3d195`](https://github.com/python/typeshed/commit/4992a813c160e037712b0793cd0488275cb3d195).